@@ -76,7 +76,7 @@ class MotionModel2D:
             return out
 
     def spline_akima(self, free_params, projection_matrices_input, return_motion_curves=False):
-        ''' Models a 3d rigid motion trajectory as 6 individual akima splines for rx, ry, rz, tx, ty, tz
+        ''' Models a 3d rigid motion trajectory as 3 individual akima splines for r, tx, ty
 
         :param free_params: params for the spline nodes; (r, tx, ty) for each node as 1D numpy array of size 3*num_nodes
         :param projection_matrices_input: the best guess for good projection matrices as 3D numpy array of size
@@ -115,9 +115,10 @@ class MotionModel2D:
         interpolated_values = np.zeros((num_projections, 3))
         interpolated_values[:self.start_projection, :] = 0
         interpolated_values[self.start_projection + self.step_length:, :] = free_params
-        interpolated_values[self.start_projection:self.start_projection + self.step_length, 0] = np.linspace(0, free_params[0], num=self.step_length, endpoint=False)
-        interpolated_values[self.start_projection:self.start_projection + self.step_length, 1] = np.linspace(0, free_params[1], num=self.step_length, endpoint=False)
-        interpolated_values[self.start_projection:self.start_projection + self.step_length, 2] = np.linspace(0, free_params[2], num=self.step_length, endpoint=False)
+        if (self.start_projection + self.step_length) < num_projections:
+            interpolated_values[self.start_projection:self.start_projection + self.step_length, 0] = np.linspace(0, free_params[0], num=self.step_length, endpoint=False)
+            interpolated_values[self.start_projection:self.start_projection + self.step_length, 1] = np.linspace(0, free_params[1], num=self.step_length, endpoint=False)
+            interpolated_values[self.start_projection:self.start_projection + self.step_length, 2] = np.linspace(0, free_params[2], num=self.step_length, endpoint=False)
 
         out = np.zeros(num_projections * 3)
         out[0::3] = interpolated_values[:, 0]
